/* $Header: profgsrc.sql 243755.1 2003/11/19 12:00:00 pkm ship $ */
SET DOC OFF;
/*============================================================================+
|    Copyright (c) 2003 Oracle Corporation Redwood Shores, California, USA    |
|                              All rights reserved.                           |
+=============================================================================+
|
| FILENAME
|
|   profgsrc.sql - Get source code for PL/SQL Library (package, procedure, function or trigger)
|
|
| USAGE
|
|   Extracts from USER_SOURCE the PL/SQL code for any application Library (i.e.
|   packages, procedures, functions or triggers).
|
|   Spool file generated by this script can be manually modified to add the
|   calls to the DBMS_PROFILE procedures in order to profile the PL/SQL Library
|   in terms of performance.
|
|   Connect into SQL*Plus as the application user who owns the PL/SQL Libary to
|   extract, and execute providing the Libary name (package, procedure,
|   function or trigger)
|
|      SQL> START profgsrc.sql <PL/SQL Library name>;
|
|
| DESCRIPTION
|
|   This script can be used on databases with RDBMS 8.1.7 or higher and it is
|   not constrained to Oracle Apps.
|
|   This script profgsrc.sql requires one parameter:
|
|   1. Corresponding to the PL/SQL Library name to extract from USER_SOURCE
|
|
| NOTES
|
|   This script is part of a set compressed into file PROF.zip.  Latest version
|   of PROF.zip can be downloaded from Note:243755.1
|
|   Documentation on using the DBMS_PROFILER can be found at:
|
|      http://download-west.oracle.com/docs/cd/B10501_01/appdev.920/a96612/d_profil.htm#1003424
|
|   Read Note:243755.1 for further details.
|
|   For feedback, email author carlos.sierra@oracle.com
|
| HISTORY
|
|   2003/07/14 CSIERRA  Created
|
+============================================================================*/

PRO Usage:
PRO sqlplus apps/<pwd>
PRO SQL> START profgsrc.sql <PL/SQL Library name>;
PRO

COL name NEW_VALUE name FORMAT A30;
COL type NEW_VALUE type FORMAT A12;

SET VER OFF FEED OFF;

SELECT object_name name, object_type type
  FROM user_objects
 WHERE object_name LIKE RTRIM(UPPER('&&1'))||'%'
   AND object_type IN ('PACKAGE BODY', 'FUNCTION', 'PROCEDURE', 'TRIGGER')
   AND ROWNUM = 1;

PRO
PRO Generating spool file for &&type &&name
PRO

SET TERM OFF PAGES 0 LIN 4000 TRIMS ON;
SPO &&name..SQL;
SELECT DECODE(line,1,'CREATE OR REPLACE ',NULL)||
       text
  FROM user_source
 WHERE name = '&&name'
   AND type = '&&type'
 ORDER BY
       line;
PRO /
SPO OFF;
UNDEF 1 name type;
CLE COL;
SET TERM ON PAGES 24 LIN 80 TRIMS OFF VER ON FEED ON DOC ON;
